@@ -29,7 +29,7 @@
 #error "Only <clutter/clutter.h> can be included directly."
 #endif
 
-#include <clutter/clutter-animation.h>
+#include <clutter/clutter-types.h>
 
 G_BEGIN_DECLS
 
@@ -97,15 +97,6 @@ struct _ClutterAnimatableIface
 
 GType clutter_animatable_get_type (void) G_GNUC_CONST;
 
-CLUTTER_DEPRECATED_FOR(clutter_animatable_interpolate_value)
-gboolean    clutter_animatable_animate_property  (ClutterAnimatable *animatable,
-                                                  ClutterAnimation  *animation,
-                                                  const gchar       *property_name,
-                                                  const GValue      *initial_value,
-                                                  const GValue      *final_value,
-                                                  gdouble            progress,
-                                                  GValue            *value);
-
 GParamSpec *clutter_animatable_find_property     (ClutterAnimatable *animatable,
                                                   const gchar       *property_name);
 void        clutter_animatable_get_initial_state (ClutterAnimatable *animatable,
