@@ -62,18 +62,60 @@ static GParamSpec *obj_props[PROP_LAST] = { NULL, };
 
 G_DEFINE_TYPE (ClutterPropertyTransition, clutter_property_transition, CLUTTER_TYPE_TRANSITION)
 
+static inline void
+clutter_property_transition_ensure_interval (ClutterPropertyTransition *transition,
+                                             ClutterAnimatable         *animatable,
+                                             ClutterInterval           *interval)
+{
+  ClutterPropertyTransitionPrivate *priv = transition->priv;
+  GValue *value_p;
+
+  if (clutter_interval_is_valid (interval))
+    return;
+
+  /* if no initial value has been set, use the current value */
+  value_p = clutter_interval_peek_initial_value (interval);
+  if (!G_IS_VALUE (value_p))
+    {
+      g_value_init (value_p, clutter_interval_get_value_type (interval));
+      clutter_animatable_get_initial_state (animatable,
+                                            priv->property_name,
+                                            value_p);
+    }
+
+  /* if no final value has been set, use the current value */
+  value_p = clutter_interval_peek_final_value (interval);
+  if (!G_IS_VALUE (value_p))
+    {
+      g_value_init (value_p, clutter_interval_get_value_type (interval));
+      clutter_animatable_get_initial_state (animatable,
+                                            priv->property_name,
+                                            value_p);
+    }
+}
+
 static void
 clutter_property_transition_attached (ClutterTransition *transition,
                                       ClutterAnimatable *animatable)
 {
   ClutterPropertyTransition *self = CLUTTER_PROPERTY_TRANSITION (transition);
   ClutterPropertyTransitionPrivate *priv = self->priv;
+  ClutterInterval *interval;
 
   if (priv->property_name == NULL)
     return;
 
-  priv->pspec = clutter_animatable_find_property (animatable,
-                                                  priv->property_name);
+  priv->pspec =
+    clutter_animatable_find_property (animatable, priv->property_name);
+
+  if (priv->pspec == NULL)
+    return;
+
+  interval = clutter_transition_get_interval (transition);
+  if (interval == NULL)
+    return;
+
+  clutter_property_transition_ensure_interval (self, animatable, interval);
 }
 
 static void
@@ -95,13 +137,19 @@ clutter_property_transition_compute_value (ClutterTransition *transition,
   ClutterPropertyTransition *self = CLUTTER_PROPERTY_TRANSITION (transition);
   ClutterPropertyTransitionPrivate *priv = self->priv;
   GValue value = G_VALUE_INIT;
+  GType p_type, i_type;
   gboolean res;
 
   /* if we have a GParamSpec we also have an animatable instance */
   if (priv->pspec == NULL)
     return;
 
-  g_value_init (&value, clutter_interval_get_value_type (interval));
+  clutter_property_transition_ensure_interval (self, animatable, interval);
+
+  p_type = G_PARAM_SPEC_VALUE_TYPE (priv->pspec);
+  i_type = clutter_interval_get_value_type (interval);
+
+  g_value_init (&value, i_type);
 
   res = clutter_animatable_interpolate_value (animatable,
                                               priv->property_name,
@@ -110,9 +158,36 @@ clutter_property_transition_compute_value (ClutterTransition *transition,
                                               &value);
 
   if (res)
-    clutter_animatable_set_final_state (animatable,
-                                        priv->property_name,
-                                        &value);
+    {
+      if (i_type != p_type || g_type_is_a (i_type, p_type))
+        {
+          if (g_value_type_transformable (i_type, p_type))
+            {
+              GValue transform = G_VALUE_INIT;
+
+              g_value_init (&transform, p_type);
+
+              if (g_value_transform (&value, &transform))
+                {
+                  clutter_animatable_set_final_state (animatable,
+                                                      priv->property_name,
+                                                      &transform);
+                }
+              else
+                g_warning ("%s: Unable to convert a value of type '%s' from "
+                           "the value type '%s' of the interval.",
+                           G_STRLOC,
+                           g_type_name (p_type),
+                           g_type_name (i_type));
+
+              g_value_unset (&transform);
+            }
+        }
+      else
+        clutter_animatable_set_final_state (animatable,
+                                            priv->property_name,
+                                            &value);
+    }
 
   g_value_unset (&value);
 }
